package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcAqyh;
import org.apache.ibatis.annotations.Param;

/**
 * 安全隐患 tc_aqyhMapper接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface TcAqyhMapper 
{
    /**
     * 查询安全隐患 tc_aqyh
     * 
     * @param id 安全隐患 tc_aqyh主键
     * @return 安全隐患 tc_aqyh
     */
    public TcAqyh selectTcAqyhById(Long id);

    /**
     * 查询安全隐患 tc_aqyh列表
     * 
     * @param tcAqyh 安全隐患 tc_aqyh
     * @return 安全隐患 tc_aqyh集合
     */
    public List<TcAqyh> selectTcAqyhList(TcAqyh tcAqyh);

    /**
     * 新增安全隐患 tc_aqyh
     * 
     * @param tcAqyh 安全隐患 tc_aqyh
     * @return 结果
     */
    public int insertTcAqyh(TcAqyh tcAqyh);

    /**
     * 修改安全隐患 tc_aqyh
     * 
     * @param tcAqyh 安全隐患 tc_aqyh
     * @return 结果
     */
    public int updateTcAqyh(TcAqyh tcAqyh);

    /**
     * 删除安全隐患 tc_aqyh
     * 
     * @param id 安全隐患 tc_aqyh主键
     * @return 结果
     */
    public int deleteTcAqyhById(Long id);

    /**
     * 批量删除安全隐患 tc_aqyh
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcAqyhByIds(Long[] ids);


    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
