package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcXtjc;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcAqyh;
import com.ruoyi.tcZz.service.ITcAqyhService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 安全隐患 tc_aqyhController
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "安全隐患")
@RequestMapping("/tcZz/networkSecurity/aqyh")
public class TcAqyhController extends BaseController
{
    @Autowired
    private ITcAqyhService tcAqyhService;

    /**
     * 查询安全隐患 tc_aqyh列表
     */
    @ApiOperation(value = "查询安全隐患列表",response =TcAqyh.class )
    @GetMapping("/list")
    public TableDataInfo list(TcAqyh tcAqyh)
    {
        startPage();
        List<TcAqyh> list = tcAqyhService.selectTcAqyhList(tcAqyh);
        return getDataTable(list);
    }

    /**
     * 导出安全隐患 tc_aqyh列表
     */
    @ApiOperation(value = "导出安全隐患列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcAqyh tcAqyh)
    {
        List<TcAqyh> list = tcAqyhService.selectTcAqyhList(tcAqyh);
        ExcelUtil<TcAqyh> util = new ExcelUtil<TcAqyh>(TcAqyh.class);
        util.exportExcel(response, list, "安全隐患 tc_aqyh数据");
    }

    /**
     * 获取安全隐患 tc_aqyh详细信息
     */
    @ApiOperation(value = "获取安全隐患详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcAqyhService.selectTcAqyhById(id));
    }

    /**
     * 新增安全隐患 tc_aqyh
     */
    @ApiOperation(value = "新增安全隐患")
    @PostMapping
    public AjaxResult add(@RequestBody TcAqyh tcAqyh)
    {
        return toAjax(tcAqyhService.insertTcAqyh(tcAqyh));
    }

    /**
     * 修改安全隐患 tc_aqyh
     */
    @ApiOperation(value = "修改安全隐患")
    @PutMapping
    public AjaxResult edit(@RequestBody TcAqyh tcAqyh)
    {
        return toAjax(tcAqyhService.updateTcAqyh(tcAqyh));
    }

    /**
     * 删除安全隐患 tc_aqyh
     */
    @ApiOperation(value = "删除安全隐患")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcAqyhService.deleteTcAqyhByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcAqyh> util = new ExcelUtil<TcAqyh>(TcAqyh.class);
        List<TcAqyh> tcXtjcList = util.importExcel(file.getInputStream());
        tcAqyhService.importUser(tcXtjcList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcAqyhService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }
    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcAqyh> util = new ExcelUtil<TcAqyh>(TcAqyh.class);
        util.importTemplateExcel(response, " 安全隐患");
    }
}
